import {
  Box,
  Container,
  Heading,
  SimpleGrid,
  Text,
  AspectRatio,
  Stack,
} from '@chakra-ui/react';
import { videoPodcasts } from '../constants/videoPodcasts';


export default function PodcastPage() {
  return (
    <Box py={10} bg="gray.50" minH="100vh">
      <Container maxW="7xl">
        <Heading as="h1" mb={8} fontSize={{ base: '3xl', md: '5xl' }}>
          Video Podcasts
        </Heading>

        <SimpleGrid columns={{ base: 1, md: 2 }} spacing={8}>
          {videoPodcasts.map((podcast) => (
            <Box
              key={podcast.id}
              bg="white"
              borderRadius="lg"
              overflow="hidden"
              boxShadow="md"
              _hover={{ boxShadow: 'lg', transform: 'scale(1.01)' }}
              transition="all 0.2s ease-in-out"
            >
              <Stack spacing={3} p={4}>
                <Heading as="h2" fontSize="lg">
                  {podcast.title}
                </Heading>
              </Stack>

              <AspectRatio ratio={16 / 9}>
                <iframe
                  src={podcast.videoUrl.replace('watch?v=', 'embed/').replace('shorts/', 'embed/')}
                  title={podcast.title}
                  allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture"
                  allowFullScreen
                  style={{ border: 'none' }}
                />
              </AspectRatio>

              <Box px={4} pb={4}>
                <Text color="gray.700">{podcast.description}</Text>
              </Box>
            </Box>
          ))}
        </SimpleGrid>
      </Container>
    </Box>
  );
}
